You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@maven.apache.org by rf...@apache.org on 2020/01/26 15:49:31 UTC

[maven-integration-testing] branch MNG-5669 updated: [MNG-5669] Fix path to local repository

This is an automated email from the ASF dual-hosted git repository.

rfscholte pushed a commit to branch MNG-5669
in repository https://gitbox.apache.org/repos/asf/maven-integration-testing.git


The following commit(s) were added to refs/heads/MNG-5669 by this push:
     new a75cbe0  [MNG-5669] Fix path to local repository
a75cbe0 is described below

commit a75cbe0a67f9899089b89dedf03f4751e4ce754a
Author: rfscholte <rf...@apache.org>
AuthorDate: Sun Jan 26 16:49:22 2020 +0100

    [MNG-5669] Fix path to local repository
---
 .gitignore                                                           | 2 +-
 .../src/test/resources/mng-5669-read-poms-once/.mvn/jvm.config       | 2 +-
 run-its.bat                                                          | 5 +++--
 run-its.sh                                                           | 5 +++--
 4 files changed, 8 insertions(+), 6 deletions(-)

diff --git a/.gitignore b/.gitignore
index c00d32a..a8e3944 100644
--- a/.gitignore
+++ b/.gitignore
@@ -1,6 +1,6 @@
 .svn
 target
-/repo
+/.repository
 .project
 .classpath
 .settings
diff --git a/core-it-suite/src/test/resources/mng-5669-read-poms-once/.mvn/jvm.config b/core-it-suite/src/test/resources/mng-5669-read-poms-once/.mvn/jvm.config
index 46fefcc..1c01bbe 100644
--- a/core-it-suite/src/test/resources/mng-5669-read-poms-once/.mvn/jvm.config
+++ b/core-it-suite/src/test/resources/mng-5669-read-poms-once/.mvn/jvm.config
@@ -1 +1 @@
--javaagent:../../../../repo/mng-coreit/javaagent/1.0-SNAPSHOT/javaagent-1.0-SNAPSHOT.jar
\ No newline at end of file
+-javaagent:../../../../.repository/mng-coreit/javaagent/1.0-SNAPSHOT/javaagent-1.0-SNAPSHOT.jar
\ No newline at end of file
diff --git a/run-its.bat b/run-its.bat
index 7fbbbb3..773af99 100644
--- a/run-its.bat
+++ b/run-its.bat
@@ -18,9 +18,10 @@
 @REM
 
 @REM How JvZ runs the ITs from a clean slate if it would be on Windows
+@REM maven.repo.local should match mavenLocalRepo in maven/Jenkinsfile
 
-mvn clean install -Prun-its,embedded -Dmaven.repo.local=%cd%\repo
+mvn clean install -Prun-its,embedded -Dmaven.repo.local=%cd%\.repository
 
 @REM If behind a proxy try this..
 
-@REM mvn clean install -Prun-its,embedded -Dmaven.repo.local=%cd%\repo -Dproxy.host=<host> -Dproxy.port=<port> -Dproxy.user= -Dproxy.pass= -Dproxy.nonProxyHosts=<hosts>
+@REM mvn clean install -Prun-its,embedded -Dmaven.repo.local=%cd%\.repository -Dproxy.host=<host> -Dproxy.port=<port> -Dproxy.user= -Dproxy.pass= -Dproxy.nonProxyHosts=<hosts>
diff --git a/run-its.sh b/run-its.sh
index d13fce6..f6fc095 100755
--- a/run-its.sh
+++ b/run-its.sh
@@ -20,9 +20,10 @@
 #
 
 # How I run the ITs from a clean slate. Though I do this with a primed Nexus instance. JvZ.
+# maven.repo.local should match mavenLocalRepo in maven/Jenkinsfile
 
-mvn clean install -Prun-its,embedded -Dmaven.repo.local=`pwd`/repo
+mvn clean install -Prun-its,embedded -Dmaven.repo.local=`pwd`/.repository
 
 # If behind a proxy try this
 
 # mvn clean install -Prun-its,embedded -Dmaven.repo.local=`pwd`/repo -Dproxy.host=<host> -Dproxy.port=<port> -Dproxy.user= -Dproxy.pass= -Dproxy.nonProxyHosts=<hosts>
@@ -20,9 +20,10 @@
 # If behind a proxy try this
 
-# mvn clean install -Prun-its,embedded -Dmaven.repo.local=`pwd`/repo -Dproxy.host=<host> -Dproxy.port=<port> -Dproxy.user= -Dproxy.pass= -Dproxy.nonProxyHosts=<hosts>
+# mvn clean install -Prun-its,embedded -Dmaven.repo.local=`pwd`/.repository -Dproxy.host=<host> -Dproxy.port=<port> -Dproxy.user= -Dproxy.pass= -Dproxy.nonProxyHosts=<hosts>